Enable checkstyle rule to catch variables that hide fields

Enable the checkstyle "HiddenFields" rule and fix any issues
that it detects.  Suppress these violations for parameters
to setters and constructors.

Added support for the checkstyle comment suppression module
// CHECKSTYLE:OFF and //CHECKSTYLE:ON are now
supported.

Suppressed HiddenField checks for net.onrc.onos.core.packet.*
rather than fix them.  These APIs are designed to
require formal parameters and local members having
the same name.

Change-Id: Ibc057603a934842d9c9b9b668f55bc5f5519e7f6
diff --git a/src/main/java/net/onrc/onos/core/util/FlowEntryErrorState.java b/src/main/java/net/onrc/onos/core/util/FlowEntryErrorState.java
index fa12055..4744baa 100644
--- a/src/main/java/net/onrc/onos/core/util/FlowEntryErrorState.java
+++ b/src/main/java/net/onrc/onos/core/util/FlowEntryErrorState.java
@@ -71,12 +71,12 @@
     /**
      * Set the values of the error type and code.
      *
      * @param type the error type to use.
      * @param code the error code to use.
      */
-    public void setValue(short type, short code) {
-        this.type = type;
-        this.code = code;
+    public void setValue(short newType, short newCode) {
+        type = newType;
+        code = newCode;
     }
 
     /**
@@ -71,12 +71,12 @@
      * Set the values of the error type and code.
      *
-     * @param type the error type to use.
-     * @param code the error code to use.
+     * @param newType the error type to use.
+     * @param newCode the error code to use.
      */